@import "lg-variables";
@import "lg-mixins";
.lg-outer.fb-comments{
    .lg-img-wrap, .lg-video-cont {
        padding-right: 400px !important;
    }
    .fb-comments {
        height: 100%;
        overflow-y: auto;
        position: absolute;
        right: 0;
        top: 0;
        width: 420px;
        z-index: 99999;
        background: #fff url("#{$lg-path-images}/loading.gif") no-repeat scroll center center;
        &.fb_iframe_widget {
            background-image: none;
            &.fb_iframe_widget_loader{
                background: #fff url("#{$lg-path-images}/loading.gif") no-repeat scroll center center;
            }
        }
    }
    .lg-toolbar {
        right: 420px;
        width: auto;
    }
    .lg-actions .lg-next {
        right: 420px;
    }
    .lg-item {
        background-image: none;
        &.lg-complete{
            .lg-img-wrap, .lg-video-cont{
                background-image: none;
            }
        } 
    }
    .lg-img-wrap, .lg-video-cont {
        background: url("#{$lg-path-images}/loading.gif") no-repeat scroll transparent;
        background-position: center center;
        background-position: calc((100% - 400px) / 2) center;
    }

    .lg-sub-html {
        padding: 0;
        position: static;
    }

    .lg-video-cont {
        max-width: 1250px !important;
    }
}
